LocsDiff

Struct LocsDiff 

pub struct LocsDiff {
    pub added: Locs,
    pub removed: Locs,
}
Lines of code diff (added vs removed).

Tracks additions and removals for each of the 6 line types.

Fields

added: Locs

Lines added

removed: Locs

Lines removed

Implementations

Source

impl LocsDiff

pub fn new() -> Self

Create a new empty diff.

pub fn net_code(&self) -> i64

Net change for code lines.

pub fn net_tests(&self) -> i64

Net change for test lines.

pub fn net_examples(&self) -> i64

Net change for example lines.

pub fn net_docs(&self) -> i64

Net change for doc comment lines.

pub fn net_comments(&self) -> i64

Net change for regular comment lines.

pub fn net_blanks(&self) -> i64

Net change for blank lines.

pub fn net_total(&self) -> i64

Net change for total lines.

pub fn filter(&self, types: LineTypes) -> Self

Return a filtered copy with only the specified line types included.