LineTypes

Struct LineTypes 

pub struct LineTypes {
    pub code: bool,
    pub tests: bool,
    pub examples: bool,
    pub docs: bool,
    pub comments: bool,
    pub blanks: bool,
    pub all: bool,
}
Filter for which line types to include in results.

The 7 line types are:

  • code: Production code logic lines
  • tests: Test code logic lines
  • examples: Example code logic lines
  • docs: Documentation comments (anywhere)
  • comments: Regular comments (anywhere)
  • blanks: Blank lines (anywhere)
  • all: Total line count (precomputed sum of all types)

When a line type is disabled, it will be zeroed in returned stats.

Fields

code: bool

Include production code logic lines

tests: bool

Include test code logic lines

examples: bool

Include example code logic lines

docs: bool

Include documentation comment lines

comments: bool

Include regular comment lines

blanks: bool

Include blank lines

all: bool

Include total line count (precomputed)

Implementations

Source

impl LineTypes

pub fn new() -> Self

Create with no types enabled (for building up). Note: all defaults to true since it’s always useful to see totals.

pub fn everything() -> Self

Include all line types

pub fn none() -> Self

Include no line types at all (not even all)

pub fn code_only() -> Self

Include only production code (plus all)

pub fn tests_only() -> Self

Include only test code (plus all)

pub fn examples_only() -> Self

Include only example code (plus all)

pub fn logic_only() -> Self

Include all logic lines (code + tests + examples + all)

pub fn with_code(self) -> Self

Builder: enable code

pub fn with_tests(self) -> Self

Builder: enable tests

pub fn with_examples(self) -> Self

Builder: enable examples

pub fn with_docs(self) -> Self

Builder: enable docs

pub fn with_comments(self) -> Self

Builder: enable comments

pub fn with_blanks(self) -> Self

Builder: enable blanks

pub fn with_all(self) -> Self

Builder: enable all (total)

pub fn without_all(self) -> Self

Builder: disable all (total)